(sec_gallery)=
# Gallery

This page includes examples that illustrate various features of Demes models,
including some well-known and more complicated models of human history.

(sec_zigzag_example)=
## Zigzag model

```{eval-rst}
.. literalinclude:: ../examples/zigzag.yaml
   :language: yaml
```

(sec_ooa_example)=
## Gutenkunst et al. (2009) Out-of-Africa expansion

```{eval-rst}
.. literalinclude:: ../examples/gutenkunst_ooa.yaml
   :language: yaml
```

(sec_denisova_example)=
## Jacobs et al. (2019) Denisovan admixture

```{eval-rst}
.. literalinclude:: ../examples/jacobs_papuans.yaml
   :language: yaml
```
